/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
  *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.bootstrap;

import java.util.Properties;

import org.jboss.bootstrap.test.common.ServerConfigUtil;
import org.jboss.util.StopWatch;

/**
 * NoInitServerImpl
 * 
 * An implementation of ServerImpl which does not perform initialization
 * such that shutdown can be tested cleanly (ie. does not rely upon complete 
 * init)
 * 
 * JBBOOT-5
 *
 * @author <a href="mailto:andrew.rubinger@jboss.org">ALR</a>
 * @version $Revision: $
 */
public class NoInitServerImpl extends AbstractServerImpl
{
   //--------------------------------------------------------------------||
   // Required Implementations ------------------------------------------||
   //--------------------------------------------------------------------||

   /* (non-Javadoc)
    * @see org.jboss.bootstrap.AbstractServerImpl#doShutdown()
    */
   @Override
   protected void doShutdown()
   {
     
   }

   /* (non-Javadoc)
    * @see org.jboss.bootstrap.AbstractServerImpl#doStart(org.jboss.util.StopWatch)
    */
   @Override
   protected void doStart(StopWatch watch) throws Throwable
   {
    
   }

   //--------------------------------------------------------------------||
   // Overridden Implementations ----------------------------------------||
   //--------------------------------------------------------------------||

   /**
    * Initialization scheme which does nothing aside set the ServerConfig
    */
   @Override
   public void init(Properties props) throws IllegalStateException, Exception
   {
      this.setConfig(ServerConfigUtil.getConfig(props));
   }

}
