/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
  *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.bootstrap.test.jboot5.unit;

import java.util.Properties;

import junit.framework.TestCase;

import org.jboss.bootstrap.NoInitServerImpl;
import org.jboss.bootstrap.spi.Server;
import org.junit.Test;

/**
 * CleanShutdownOnIncompleteInitTestCase
 * 
 * Tests that AbstractServerImpl can startup/shutdown cleanly
 * even when initialization has not yet been completely 
 * performed
 * 
 * JBBOOT-5
 *
 * @author <a href="mailto:andrew.rubinger@jboss.org">ALR</a>
 * @version $Revision: 85188 $
 */
public class CleanShutdownOnIncompleteInitTestCase
{

   /**
    * 
    * @throws Exception
    */
   @Test
   public void testCleanShutdownWithNoInit() throws Exception
   {

      // Create and perform minimal initialization upon a new server
      Server server = new NoInitServerImpl();
      server.init(new Properties());

      // Startup and shutdown
      try
      {
         server.start();
         server.shutdown();
      }
      catch (Exception e)
      {
         e.printStackTrace();
         TestCase.fail("Startup/shutdown sequence without proper configuration should be clean, got exception: " + e);
      }

   }

}
