/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
  *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.bootstrap.test.jboot6.unit;

import java.util.Properties;

import junit.framework.TestCase;

import org.jboss.bootstrap.BaseServerConfig;
import org.jboss.bootstrap.ServerConfigExposition;
import org.jboss.bootstrap.spi.ServerConfig;
import org.jboss.bootstrap.test.common.ServerConfigUtil;
import org.junit.Test;

/**
 * GetServerNativeDirPropertyTestCase
 * 
 * Ensures that the SERVER_NATIVE_DIR property
 * is obtained from internal property set,
 * not from System properties
 * 
 * JBBOOT-6
 *
 * @author <a href="mailto:andrew.rubinger@jboss.org">ALR</a>
 * @version $Revision: $
 */
public class GetServerNativeDirPropertyTestCase
{
   //--------------------------------------------------------------------||
   // Tests -------------------------------------------------------------||
   //--------------------------------------------------------------------||

   /**
    * Tests that BaseServerConfig.getNativeDirProperty uses its own properties,
    * and not that of System.getProperty
    */
   @Test
   public void testGetNativeDirProperty() throws Exception
   {
      // Initialize
      String expectedNativeDir = "expected";
      String wrongNativeDir = "wrong";

      // Create properties for the server config
      Properties configProps = new Properties();
      configProps.put(ServerConfig.NATIVE_DIR_PROPERTY, expectedNativeDir);

      // Set a system property for native dir
      System.getProperties().put(ServerConfig.NATIVE_DIR_PROPERTY, wrongNativeDir);

      // Create the config
      BaseServerConfig config = ServerConfigUtil.getConfig(configProps);

      // Test the native dir is expected
      String nativeDirProperty = ServerConfigExposition.getNativeDirProperty(config);
      TestCase.assertEquals("NATIVE_DIR was not as passed in properties to config", expectedNativeDir,
            nativeDirProperty);

   }
}
